### Name: pcAlgo
### Title: PC-Algorithm: Estimate the Underlying Graph (Skeleton) of a DAG
### Aliases: pcAlgo
### Keywords: multivariate models graphs

### ** Examples

p <- 10
## generate and draw random DAG :
set.seed(101)
class(myDAG <- randomDAG(p, prob = 0.2))
plot(myDAG, main = "randomDAG(10, prob = 0.2)")

## generate 1000 samples of DAG using standard normal error distribution
n <- 1000
d.mat <- rmvDAG(n, myDAG, errDist = "normal")

## estimate skeleton given data
res <- pcAlgo(d.mat, alpha = 0.05, corMethod = "standard")
res
plot(res)# << using the plot() method for 'pcAlgo' objects!
str(res, max = 2)
(c.g <- compareGraphs(myDAG, res@graph))
## plot the original DAG and the estimated skeleton :
op <- par(mfrow=c(2,1))
plot(myDAG, main = "original (random)DAG")
plot(res@graph,
     main = "estimated skeleton from pcAlgo(<simulated, n = 1000>)")
par(op)

## generate data containing severe outliers
d.mixmat <- rmvDAG(n, myDAG, errDist = "mix", mix=0.3)
## Compute "classical" and robust estimate of skeleton :
pcC <- pcAlgo(d.mixmat, 0.01, corMeth = "standard")
pcR <- pcAlgo(d.mixmat, 0.01, corMeth = "Qn")
str(pcR, max = 2)
(c.Cg <- compareGraphs(myDAG, pcC@graph))
(c.Rg <- compareGraphs(myDAG, pcR@graph))#-> (.201 0 1) much better
op <- par(mfrow=c(3,1))
  plot(myDAG, main = "original (random)DAG")
  plot(pcC)
  plot(pcR)
par(op)



